# API reference

## Plotting

```{eval-rst}
.. currentmodule:: plopp

.. autosummary::
   :toctree: ../generated

   plot
   slicer
   superplot
   inspector
   scatter
   scatter3d
   xyplot
```

## Core

```{eval-rst}
.. autosummary::
   :toctree: ../generated

   core.Node
   core.View
   core.node
   core.widget_node
   core.show_graph
```

## Graphics

```{eval-rst}
.. autosummary::
   :toctree: ../generated

   graphics.Camera
   graphics.ColorMapper
   graphics.figure1d
   graphics.figure2d
   graphics.figure3d
   graphics.imagefigure
   graphics.ImageView
   graphics.linefigure
   graphics.LineView
   graphics.scatterfigure
   graphics.ScatterView
   graphics.scatter3dfigure
   graphics.Scatter3dView
   graphics.tiled
```

## Widgets and tools

```{eval-rst}
.. autosummary::
   :toctree: ../generated

   widgets.Box
   widgets.Checkboxes
   widgets.HBar
   widgets.RangeSliceWidget
   widgets.SliceWidget
   widgets.VBar

   widgets.tools.AxesTool
   widgets.tools.ButtonTool
   widgets.tools.CameraTool
   widgets.tools.ColorTool
   widgets.tools.HomeTool
   widgets.tools.LogNormTool
   widgets.tools.LogxTool
   widgets.tools.LogyTool
   widgets.tools.MultiToggleTool
   widgets.tools.OutlineTool
   widgets.tools.PanZoomTool
   widgets.tools.SaveTool
   widgets.tools.ToggleTool

   widgets.drawing.DrawingTool
   widgets.drawing.PointsTool

   widgets.clip3d.Clip3dTool
   widgets.clip3d.ClippingPlanes
   widgets.cut3d.Cut3dTool
   widgets.cut3d.TriCutTool
```

## Backends

```{eval-rst}
.. toctree::
   :maxdepth: 1

   matplotlib
   plotly
   pythreejs
```

## Other

```{eval-rst}
.. autosummary::
   :toctree: ../generated

   show
```
